#!/usr/bin/env python
#
# Copyright (C) 2005 Nicolas Burrus
# This file is part of Tidydoc.
#
# Tidydoc is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Tidydoc is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from getopt import getopt
import os, sys

from td_config import config, read_config
import td_dsc
import td_tools

def print_help():
  sys.stderr.write(
"""Usage: td-upload [options] document_file description_file

  Options

  -c, --config configfile  Config file to use.
  -v, --version            Print version number.

Nicolas Burrus <nes@lrde.epita.fr>
""")

def parse_command_line(argv):
  try: (options, args) =  getopt(argv[1:], "vc:", ["version", "config"])
  except:
    print_help()
    sys.exit(1)

  if len(args) != 2:
    print_help()
    sys.exit(1)

  cmd_options = {}
  cmd_options['doc_file'] = args[0]
  cmd_options['dsc_file'] = args[1]
  cmd_options['config_file'] = None

  for option in options:
    if option[0] == "-v" or option[0] == "--version":
      print "Tidydoc " + ac_config.version
      print "Nicolas Burrus <nes@lrde.epita.fr>"
      sys.exit(0)
    if option[0] == "-c" or option[0] == "--config":
      cmd_options['config_file'] = option[1]

  return cmd_options

def upload(orig_doc_path, orig_dsc_path):
  dsc_sections = td_dsc.parse(orig_dsc_path)

  # Compute destination filenames.
  final_doc_name = td_dsc.docname_from_dsc(dsc_sections, orig_doc_path)
  final_dsc_name = final_doc_name + ".dsc"

  # Extract the first category.
  categories = dsc_sections['Categories']
  if len(categories) == 0:
    categories = ["unsorted"]

  first_category = categories[0]
  first_destdir = os.path.join(config['upload_dest_path'], first_category)

  # Add files into the directories corresponding to the categories.
  upload_cmd = ""
  for category in categories:
    destdir = os.path.join(config['upload_dest_path'], category)

    # For the first category, the file will be copied.
    if (category == first_category):
      upload_cmd += config['upload_commands'] % locals()
    else:
      # For the other categories, a link is enough.
      rel_first_destdir = ".."
      for i in range(0, category.count('/')):
        rel_first_destdir += "/.."
      rel_first_destdir += '/' + first_category
      upload_cmd += config['link_commands'] % locals()

  print "`" + orig_doc_path + "' ==> `" + final_doc_name + "'"
  for category in categories:
    print " " * len(orig_doc_path) + "   ==> " + category + "/"

  print "Is this ok ? [y/n]"
  ans = sys.stdin.readline()
  if (ans.lower() != "y\n"):
    print "Aborting..."
    sys.exit (1)
  else:
    print "Ok, copying files..."

  # Execute commands
  (status, lines) = td_tools.exec_commands(upload_cmd)
  if status != 0:
    print "Error while uploading:"
    print "\n".join(lines)
    sys.exit(1)

def __main__():
  cmd_options = parse_command_line(sys.argv)
  read_config(cmd_options['config_file'])
  upload(cmd_options['doc_file'], cmd_options['dsc_file'])

if __name__ == "__main__":
  __main__()
